# s-ul.eu
An API wrapper for [s-ul.eu](https://s-ul.eu) for upload file thing.

# How to use
This module support
- Upload a file
- Delete a file
- Convert picture from s-ul.eu to thumbnail or embed for the love of the god that discord don't support 10MB picture.
- Upload text from clipboard
- Upload Screenshot from clipboard
For documentation please visit [here](https://suleu.rukchadisa.live).
